<?php
/**
 * sq language file
 *
 * This file was initially built by fetching translations from other
 * Wiki projects. See the @url lines below. Additional translations
 * and fixes where done for DokuWiki by the people mentioned in the
 * lines starting with @author
 *
 * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesSq.php?view=co
 * @author Leonard Elezi <leonard.elezi@depinfo.info>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '"';
$lang['doublequoteclosing']    = '"';
$lang['singlequoteopening']    = '\'';
$lang['singlequoteclosing']    = '\'';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Redaktoni këtë faqe';
$lang['btn_source']            = 'Trego kodin burim të faqes';
$lang['btn_show']              = 'Trego faqen';
$lang['btn_create']            = 'Krijo këtë faqe';
$lang['btn_search']            = 'Kërko';
$lang['btn_save']              = 'Ruaj';
$lang['btn_preview']           = 'Shikim paraprak';
$lang['btn_top']               = 'Kthehu ne krye';
$lang['btn_newer']             = '<< më të hershme';
$lang['btn_older']             = 'më të vonshme';
$lang['btn_revs']              = 'Shqyrtime të vjetra';
$lang['btn_recent']            = 'Ndryshime së fundmi';
$lang['btn_upload']            = 'Ngarko';
$lang['btn_cancel']            = 'Harroji';
$lang['btn_index']             = 'Kreu';
$lang['btn_secedit']           = 'Redaktoni';
$lang['btn_login']             = 'Hyrje';
$lang['btn_logout']            = 'Dalje';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Përditëso';
$lang['btn_delete']            = 'Fshi';
$lang['btn_back']              = 'Mbrapa';
$lang['btn_backlink']          = 'Lidhjet këtu';
$lang['btn_backtomedia']       = 'Mbrapa tek Përzgjedhja e Media-ve';
$lang['btn_subscribe']         = 'Menaxho Abonimet';
$lang['btn_profile']           = 'Përditëso Profilin';
$lang['btn_reset']             = 'Rivendos';
$lang['btn_draft']             = 'Redakto skicën';
$lang['btn_recover']           = 'Rekupero skicën';
$lang['btn_draftdel']          = 'Fshi skicën';
$lang['btn_revert']            = 'Kthe si më parë';
$lang['btn_register']          = 'Regjsitrohuni';
$lang['loggedinas']            = 'Regjistruar si ';
$lang['user']                  = 'Nofka e përdoruesit:';
$lang['pass']                  = 'Fjalëkalimi';
$lang['newpass']               = 'Fjalëkalim i ri';
$lang['oldpass']               = 'Konfirmo fjalëkalimin aktual';
$lang['passchk']               = 'Edhe një herë';
$lang['remember']              = 'Më mbaj mend';
$lang['fullname']              = 'Emri i vërtetë';
$lang['email']                 = 'Adresa e email-it*';
$lang['profile']               = 'Profili i përdoruesit';
$lang['badlogin']              = 'Na vjen keq, emri ose fjalëkalimi është gabim.';
$lang['minoredit']             = 'Ndryshime të Vogla';
$lang['draftdate']             = 'Skica u ruajt automatikisht në';
$lang['nosecedit']             = 'Faqja u ndryshua ndëwrkohë, informacioni i kwtij seksioni ishte i vjetër, u ngarkua faqja e tërë në vend të saj.';
$lang['regmissing']            = 'Na vjen keq, duhet të plotësoni të gjitha fushat.';
$lang['reguexists']            = 'Na vjen keq, ekziston një përdorues tjetër me të njëjtin emër.';
$lang['regsuccess']            = 'Përdoruesi u regjistrua dhe fjalëkalimi u dërgua me email.';
$lang['regsuccess2']           = 'Llogarija e Përdoruesit u krijua';
$lang['regmailfail']           = 'Duket se ka ndodhur një gabim gjatë dërgimit të fjalëkalimit me e-mail. Ju lutemi kontaktoni administratorin!';
$lang['regbadmail']            = 'Adresa email e dhënë nuk mund të pranohet sepse nuk duket e rregullt. Ju lutem fusni një adresë të rregullt ose boshatisni kutinë e shtypit.';
$lang['regbadpass']            = 'Dy fjalëkalimet e dhëna nuk janë njësoj, ju lutemi provoni përsëri.';
$lang['regpwmail']             = 'Fjalëkalimi juaj i DokuWiki-it.';
$lang['reghere']               = 'Ende nuk keni llogari? Hap një';
$lang['profna']                = 'Ky wiki nuk e lejon ndryshimin e profilit.';
$lang['profnochange']          = 'Asnjë ndryshim, asgjë për të bërë.';
$lang['profnoempty']           = 'Një emër bosh ose adresë email-i bosh nuk lejohet.';
$lang['profchanged']           = 'Profili i përdoruesit u përditësua me sukses.';
$lang['pwdforget']             = 'E harruat fjalëkalimin? Merni një të ri';
$lang['resendna']              = 'Ky wiki nuk e lejon ridërgimin e fjalëkalimeve.';
$lang['resendpwdmissing']      = 'Na vjen keq, duhet t\'i plotësoni të gjitha fushat.';
$lang['resendpwdnouser']       = 'Na vjen keq, nuk mund ta gjejmë këtë përdorues në bazën tonë të të dhënave.';
$lang['resendpwdbadauth']      = 'Na vjen keq, ky kod autorizimi nuk është i vlefshëm. Sigurohuni që përdoret linkun e plotë të konfirmimit.';
$lang['resendpwdconfirm']      = 'U dërgua një link konfirmimi nëpërmjet eMail-it.';
$lang['resendpwdsuccess']      = 'Fjalëkalimi juaj i ri u dërgua nëpërmjet eMail-it.';
$lang['license']               = 'Përveç rasteve të përcaktuara, përmbajtja në këtë wiki është e liçnsuar nën liçensën e mëposhtme:';
$lang['licenseok']             = 'Shënim: Duke redaktuar këtë faqe ju bini dakort të liçensoni përmbajtjen tuaj nën liçensën e mëposhtme:';
$lang['searchmedia']           = 'Kërko emrin e skedarit:';
$lang['searchmedia_in']        = 'Kërko në %s';
$lang['txt_upload']            = 'Zgjidh skedarin për ngarkim';
$lang['txt_filename']          = 'Ngarko si (alternative)';
$lang['txt_overwrt']           = 'Zëvendëso skedarin ekzistues';
$lang['lockedby']              = 'Kyçur momentalisht nga';
$lang['lockexpire']            = 'Kyçi skadon në';
$lang['js']['willexpire']            = 'Kyçi juaj për redaktimin e kësaj faqeje është duke skaduar.\nPër të shmangur konflikte përdorni butonin Shiko Paraprakisht për të rivendosur kohën e kyçjes.';
$lang['js']['notsavedyet']     = 'Ndryshimet e paruajtura do të humbasin.\nVazhdo me të vërtetë?';
$lang['rssfailed']             = 'Ndoshi një gabim gjatë kapjes së këtij lajmi:';
$lang['nothingfound']          = 'Nuk u gjet asgjë.';
$lang['mediaselect']           = 'Skedarët e Medias';
$lang['fileupload']            = 'Ngarkoje';
$lang['uploadsucc']            = 'Ngarkim i suksesshëm';
$lang['uploadfail']            = 'Ngarkimi dështoi. Ndoshta leje të gabuara?';
$lang['uploadwrong']           = 'Ngarkimi u refuzua! Prapashtesa e skedarit është e ndaluar!';
$lang['uploadexist']           = 'Skedari ekziston. Nuk u bë asgjë.';
$lang['uploadbadcontent']      = 'Përmbajtja e ngarkimit nuk përkoi me prapshtesën e skedarit %s';
$lang['uploadspam']            = 'Ngarkimi u bllokua nga lista e zezë e spam-eve.';
$lang['uploadxss']             = 'Ngarkimi u bllokua për dyshim përmbajtjeje jo të sigurt.';
$lang['uploadsize']            = 'Skedari i ngarkuar ishte tepër i madh. (maksimumi %s)';
$lang['deletesucc']            = 'Skedari "%s" u fshi.';
$lang['deletefail']            = '"%s" nuk mundi të fshihej. Kontrollo lejet.';
$lang['mediainuse']            = 'Skedari "%s" nuk u fshi - është ende në përdorim.';
$lang['namespaces']            = 'Hapësirat e Emrave';
$lang['mediafiles']            = 'Skedarët e disponueshëm në';
$lang['js']['searchmedia']     = 'Kërko për skedarë';
$lang['js']['keepopen']        = 'Mbaje dritaren të hapur gjatë përzgjedhjes';
$lang['js']['hidedetails']     = 'Fshih Detajet';
$lang['js']['nosmblinks']      = 'Lidhja te Windows shares funksionon vetëm në Microsoft Internet Explorer. Ju prapë mund ta kopjoni dhe ngjitni linkun.';
$lang['js']['linkwiz']         = 'Magjistari i Link';
$lang['js']['linkto']          = 'Lidh tek:';
$lang['js']['del_confirm']     = 'Fshiji vërtetë objektet e përzgjedhura?';
$lang['mediausage']            = 'Përdor sintaksën e mëposhtme për të referuar këtë skedar:';
$lang['mediaview']             = 'Shiko skedarin origjinal';
$lang['mediaroot']             = 'rrënja';
$lang['mediaupload']           = 'Ngarko një skedar tek hapësira e emrit aktuale këtu. Për të krijuaj nënhapësira emri, bashkangjiti ato pas emrit të skedarit "Ngarko Si" duke e ndarë me dy pika (:).';
$lang['mediaextchange']        = 'Prapashtesa e skedarit u ndërrua nga .%s në .%s!';
$lang['reference']             = 'Referenca për:';
$lang['ref_inuse']             = 'Skedari nuk mund të fshihet, sepse është duke u përdorur ende nga faqet e mëposhtme:';
$lang['ref_hidden']            = 'Disa referenca janë në faqe të cilat ju nuk keni leje t\'i lexoni.';
$lang['hits']                  = 'Pamje';
$lang['quickhits']             = 'Emrat e faqeve që përkojnë';
$lang['toc']                   = 'Tabela e Përmbajtjeve';
$lang['current']               = 'aktuale';
$lang['yours']                 = 'Versioni Juaj';
$lang['diff']                  = 'Trego ndryshimet nga rishikimet aktuale';
$lang['diff2']                 = 'Trego ndryshimet mes rishikimeve të përzgjedhura';
$lang['line']                  = 'Vijë';
$lang['breadcrumb']            = 'Gjurmë';
$lang['youarehere']            = 'Ju jeni këtu';
$lang['lastmod']               = 'Redaktuar për herë të fundit';
$lang['by']                    = 'nga';
$lang['deleted']               = 'u fshi';
$lang['created']               = 'u krijua';
$lang['restored']              = 'Kthehu tek një version i vjetër (%s)';
$lang['external_edit']         = 'redaktim i jashtëm';
$lang['summary']               = 'Përmbledhja redaktimit';
$lang['noflash']               = 'Nevojitet <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> për të paraqitur këtë përmbajtje.';
$lang['download']              = 'Shkarko Copën';
$lang['mail_newpage']          = 'faqje u shtua:';
$lang['mail_changed']          = 'faqja u ndryshua:';
$lang['mail_subscribe_list']   = 'faqet u ndryshuan në hapësirën e emrave:';
$lang['mail_new_user']         = 'përdorues i ri:';
$lang['mail_upload']           = 'skedari u ngarkua:';
$lang['qb_bold']               = 'Tekst i Theksuar';
$lang['qb_italic']             = 'Tekst i Pjerrët';
$lang['qb_underl']             = 'Tekst i Nënvijëzuar';
$lang['qb_code']               = 'Tekst Kodi';
$lang['qb_strike']             = 'Tekst me Vijë Mespërmes';
$lang['qb_h1']                 = 'Titull me Nivel 1';
$lang['qb_h2']                 = 'Titull me Nivel 2';
$lang['qb_h3']                 = 'Titull me Nivel 3';
$lang['qb_h4']                 = 'Titull me Nivel 4';
$lang['qb_h5']                 = 'Titull me Nivel 5';
$lang['qb_h']                  = 'Titull';
$lang['qb_hs']                 = 'Përzgjidh Titull';
$lang['qb_hplus']              = 'Titull Më i Lartë';
$lang['qb_hminus']             = 'Titull Më i Ulët';
$lang['qb_hequal']             = 'Titull i të Njëjtit Nivel';
$lang['qb_link']               = 'Lidhje e Brendshme';
$lang['qb_extlink']            = 'Lidhje e Jashtme ';
$lang['qb_hr']                 = 'Vijë Horizontale';
$lang['qb_ol']                 = 'Listë Objektesh të Renditur';
$lang['qb_ul']                 = 'Listë Objektesh të Parenditura';
$lang['qb_media']              = 'Shto imazhe dhe skedarë të tjerë';
$lang['qb_sig']                = 'Fut Firmën';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Karaktere Speciale';
$lang['upperns']               = 'kërce tek hapësira e emrit prind';
$lang['admin_register']        = 'Shto Përdorues të Ri';
$lang['metaedit']              = 'Redakto Metadata';
$lang['metasaveerr']           = 'Shkrimi i metadata-ve dështoi';
$lang['metasaveok']            = 'Metadata u ruajt';
$lang['btn_img_backto']            = 'Mbrapa te %s';
$lang['img_title']             = 'Titulli ';
$lang['img_caption']           = 'Titra';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Emri Skedarit';
$lang['img_fsize']             = 'Madhësia';
$lang['img_artist']            = 'Autor';
$lang['img_copyr']             = 'Mbajtësi i të drejtave të autorit';
$lang['img_format']            = 'Formati';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Fjalë Kyçe';
$lang['subscr_subscribe_success'] = 'Iu shtua %s listës së abonimeve për %s';
$lang['subscr_subscribe_error'] = 'Gabim gjatë shtimit të %s listës së abonimeve për %s';
$lang['subscr_subscribe_noaddress'] = 'Nuk ekziston asnjë adresë e lidhur me regjistrimin tuaj, ju nuk mund t\'i shtoheni listës së abonimeve.';
$lang['subscr_unsubscribe_success'] = 'U hoq %s nga lista e abonimeve për %s';
$lang['subscr_unsubscribe_error'] = 'Gabim në heqjen e %s nga lista e abonimeve për %s';
$lang['subscr_already_subscribed'] = '%s është abonuar njëherë te %s';
$lang['subscr_not_subscribed'] = '%s nuk është abonuar te %s';
$lang['subscr_m_not_subscribed'] = 'Momentalisht ju nuk jeni i abonuar në faqen aktuale apo hapësirën e emrit aktual.';
$lang['subscr_m_new_header']   = 'Shto abonim';
$lang['subscr_m_current_header'] = 'Abonimet aktuale';
$lang['subscr_m_unsubscribe']  = 'Fshi Abonimin';
$lang['subscr_m_subscribe']    = 'Abonohu';
$lang['subscr_m_receive']      = 'Mer';
$lang['subscr_style_every']    = 'email mbi çdo ndryshim';
$lang['authtempfail']          = 'Autentikimi i përdoruesve është përkohësisht i padisponueshëm. Nëse kjo gjendje vazhdon, ju lutemi të informoni Administratorin tuaj të Wiki-it.';
$lang['i_chooselang']          = 'Zgjidhni gjuhën tuaj';
$lang['i_installer']           = 'Installer-i DokuWiki';
$lang['i_wikiname']            = 'Emri Wiki-it';
$lang['i_enableacl']           = 'Aktivizo ACL (rekomanduar)';
$lang['i_superuser']           = 'Superpërdorues';
$lang['i_problems']            = 'Installer-i gjeti disa probleme, të shfaqura më poshtë. Nuk mund të vazhdoni derisa t\'i keni rregulluar.';
$lang['i_modified']            = 'Për arsye sigurie ky skript do të punojë vetëm me një instalim të ri dhe të pamodifikuar DokuWiki.
Ose duhet të ekstraktoni skedarët nga e para nga pakoja e shkarkimit ose konsultohuni me <a href="http://dokuwiki.org/install">Dokuwiki installation instructions</a>';
$lang['i_funcna']              = 'Funksioni PHP <code>%s</code> nuk është i disponueshëm. Mbase siguruesi juaj i host-it e ka çaktivizuar për ndonjë arsye?';
$lang['i_phpver']              = 'Versioni juaj i PHP <code>%s</code> është më i vogël se ai i duhuri <code>%s</code>. Duhet të përditësoni instalimin tuaj të PHP-së.';
$lang['i_permfail']            = '<code>%s</code> nuk është e shkruajtshme nga DokuWiki. Duhet të rregulloni lejet e përdorimit për këtë direktori.';
$lang['i_confexists']          = '<code>%s</code> ekziston njëherë';
$lang['i_writeerr']            = '<code>%s</code> nuk mundi të krijohej. Duhet të kontrolloni lejet e dirkektorisë/skedarit dhe ta krijoni skedarin manualisht.';
$lang['i_badhash']             = 'dokuwiki.php e panjohur ose e ndryshuar (hash=code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - vlerë e palejuar ose boshe';
$lang['i_success']             = 'Konfigurimi u mbarua me sukses. Tani mund ta fshini skedarin install.php. Vazhdoni tek <a href="doku.php?id=wiki:welcome">DokuWiki juaj i ri.</a>.';
$lang['i_failure']             = 'Ndodhën disa gabime gjatë shkrimit të skedarit të konfigurimit. Do t\'ju duhet t\'i rregulloni manualisht para se të përdorni <a href="doku.php?id=wiki:welcome">DokuWiki-in tuaj të ri.</a>.';
$lang['i_policy']              = 'Veprimi fillestar ACL';
$lang['i_pol0']                = 'Wiki i Hapur (lexim, shkrim, ngarkim për këdo)';
$lang['i_pol1']                = 'Wiki Publike (lexim për këdo, shkrim dhe ngarkim për përdoruesit e regjistruar)';
$lang['i_pol2']                = 'Wiki e Mbyllur (lexim, shkrim, ngarkim vetëm për përdoruesit e regjistruar)';
$lang['i_retry']               = 'Provo Përsëri';
$lang['recent_global']         = 'Momentalisht jeni duke parë ndryshimet brenda hapësirës së emrit <b>%s</b>. Gjithashtu mund <a href="%s">të shihni ndryshimet më të fundit në të gjithë wiki-n</a>.';
$lang['years']                 = '%d vite më parë';
$lang['months']                = '%d muaj më parë';
$lang['weeks']                 = '%d javë më parë';
$lang['days']                  = '%d ditë më parë';
$lang['hours']                 = '%d orë më parë';
$lang['minutes']               = '%d minuta më parë';
$lang['seconds']               = '%d sekonda më parë';
